﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;

namespace XamDataChartPerformance
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void click_Click(object sender, RoutedEventArgs e)
        {
            var dataList = new List<TestData>();
            dataList.Add(new TestData());
            dataList.Add(new TestData());

            var yAxis = theChart.Axes.OfType<NumericYAxis>().FirstOrDefault();
            if (yAxis == null)
            {
                yAxis = new NumericYAxis();
            }
            theChart.Axes.Clear();
            theChart.Axes.Add(yAxis);

            theChart.Series.Clear();

            double min = double.MaxValue;
            double max = double.MinValue;

            foreach (var data in dataList)
            {
                if (data.Min < min)
                {
                    min = data.Min;
                }
                if (data.Max > max)
                {
                    max = data.Max;
                }

                var series = new ColumnSeries();
                series.Resolution = 1;
                series.ItemsSource = data;
                series.ValueMemberPath = "Value";
                series.YAxis = yAxis;

                var xAxis = new CategoryDateTimeXAxis();
                xAxis.DateTimeMemberPath = "Date";
                xAxis.Label = "{Date}";
                xAxis.ItemsSource = data;
                if (dataList.IndexOf(data) != 0)
                {
                    var labelSettings = new AxisLabelSettings();
                    labelSettings.Visibility = System.Windows.Visibility.Collapsed;
                    xAxis.LabelSettings = labelSettings;
                    xAxis.MajorStroke = new SolidColorBrush() { Color = Colors.Transparent };
                }
                theChart.Axes.Add(xAxis);

                series.XAxis = xAxis;
                theChart.Series.Add(series);
            }
        }
    }
    public class TestData
       : ObservableCollection<TestDataItem>
    {
        private static Random _random = new Random();

        public double Max { get; set; }
        public double Min { get; set; }
        public double Range
        {
            get
            {
                return Max - Min;
            }
        }

        public TestData()
        {
            double curr = 10;
            Min = double.MaxValue;
            Max = double.MinValue;
            DateTime startDate = DateTime.Now;

            for (int i = 0; i < 15000; i++)
            {
                if (_random.NextDouble() < .5)
                {
                    curr += _random.NextDouble() * 2.0;
                }
                else
                {
                    curr -= _random.NextDouble() * 2.0;
                }

                if (curr < Min)
                {
                    Min = curr;
                }
                if (curr > Max)
                {
                    Max = curr;
                }

                Add(new TestDataItem()
                {
                    Date = startDate.AddDays(i - 10),
                    Value = curr
                });
            }
        }
    }

    public class TestDataItem
    {
        public DateTime Date { get; set; }
        public double Value { get; set; }
    }

}